<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d associatie';
$lang['%d associations'] = '%d associaties';
$lang['%d album including'] = '%d categorie waarvan ';
$lang['%d albums including'] = '%d categorieën waarvan ';
$lang['%d physical'] = '%d fysiek';
$lang['%d physical'] = '%d fysiek';
$lang[' and %d virtual'] = ' en %d virtueel';
$lang[' and %d virtual'] = ' en %d virtueel';
$lang['%d album moved'] = '%d categorie verplaatst';
$lang['%d albums moved'] = '%d categorieën verplaatst';
$lang['%d group'] = '%d groep';
$lang['%d groups'] = '%d groepen';
$lang['%d member'] = '%d lid';
$lang['%d members'] = '%d leden';
$lang['%d tag'] = '%d tag';
$lang['%d tags'] = '%d tags';
$lang['%d user comment rejected'] = '%d gebruikers commentaar afgewezen';
$lang['%d user comments rejected'] = '%d gebruikers commentaren afgewezen';
$lang['%d user comment validated'] = '%d gebruikers commentaar bevestigd';
$lang['%d user comments validated'] = '%d gebruikers commentaren bevestigd';
$lang['%d user deleted'] = '%d gebruiker verwijderd';
$lang['%d users deleted'] = '%d gebruikers verwijderd';
$lang['%d user'] = '%d gebruiker';
$lang['%d users'] = '%d gebruikers';
$lang['%d waiting for validation'] = '%d wachten op bevestiging';
$lang['Actions'] = 'Acties';
$lang['Activate'] = 'Activeer';
$lang['Add/delete a permalink'] = 'Toevoegen/verwijderen van een permalink';
$lang['Add a tag'] = 'Voeg een tag toe';
$lang['Add a user'] = 'Voeg een gebruiker toe';
$lang['Add group'] = 'Voeg een groep toe';
$lang['Add'] = 'Toevoegen';
$lang['Allow user registration'] = 'Sta gebruikersregistratie toe';
$lang['Apply to sub-albums'] = 'Toestaan op sub-categorieën';
$lang['Associated'] = 'Gelinkt';
$lang['Batch management'] = 'Batch management';
$lang['Caddie management'] = 'Winkelmandje management';
$lang['Caddie'] = 'Winkelmandje';
$lang['Albums authorized thanks to group associations'] = 'Categorieën geautoriseerd dankzij groepassociaties';
$lang['Album manual order was saved'] = 'Categorieën handmatig gesorteerd is opgeslagen';
$lang['Check for upgrade failed for unknown reasons.'] = 'Upgradecontrole is door onbekende reden niet (goed) uitgevoerd.';
$lang['Check for upgrade'] = 'Upgradecontrole';
$lang['Comments for all'] = 'Iedereen mag commentaar geven (ook gasten)';
$lang['Current name'] = 'Huidige naam';
$lang['Database'] = 'Database';
$lang['Deactivate'] = 'Deactiveer';
$lang['Delete Representant'] = 'Verwijder Representant';
$lang['Delete selected tags'] = 'Verwijder geselecteerde tags';
$lang['Delete selected users'] = 'Verwijder geselecteerde gebruikers';
$lang['Deletions'] = 'Verwijderen';
$lang['Deny selected groups'] = 'Verbiedt geselecteerde groepen';
$lang['Deny selected users'] = 'Verbiedt geselecteerde gebruikers';
$lang['Description'] = 'Omschrijving';
$lang['Display options'] = 'Toon opties';
$lang['Dissociated'] = 'Niet gelinkt';
$lang['Does not represent'] = 'Representeerd niet';
$lang['Edit selected tags'] = 'Bewerk geselecteerde tags';
$lang['Edit tags'] = 'Bewerk tags';
$lang['Email admins when a new user registers'] = 'Stuur email naar beheerders wanneer een nieuwe gebruiker zich heeft geregistreerd';
$lang['Email admins when a valid comment is entered'] = 'Stuur email naar beheerders wannneer een geldig commentaar is ingevuld';
$lang['Email admins when a comment requires validation'] = 'Stuur email naar beheerders wanneer een commantaar validatie nodig heeft';
$lang['Environment'] = 'Omgeving';
$lang['Form'] = 'Formulier';
$lang['Gallery title'] = 'Galerie-titel';
$lang['Grant selected groups'] = 'Toegang geselecteerde groepen';
$lang['Grant selected users'] = 'Toegang geselecteerde gebruikers';
$lang['Group name'] = 'Groepsnaam';
$lang['Groups'] = 'Groepen';
$lang['Guests'] = 'Gasten';
$lang['History'] = 'Geschiedenis';
$lang['Informations'] = 'Informatie';
$lang['Install'] = 'Installeer';
$lang['Link all album photos to a new album'] = 'Link alle categorie-afbeeldingen aan een nieuwe categorie';
$lang['Link all album photos to some existing albums'] = 'Link alle categorie-afbeeldingen aan bestaande categorieën';
$lang['Linked albums'] = 'Gelinkte categorieën';
$lang['Lock gallery'] = 'Sluit galerie voor onderhoud';
$lang['Maintenance'] = 'Onderhoud';
$lang['Edit album permissions'] = 'Beheer rechten van een categorie';
$lang['Manage permissions for group "%s"'] = 'Beheer rechten van groep "%s"';
$lang['Manage permissions for user "%s"'] = 'Beheer rechten van gebruiker "%s"';
$lang['Manage tags'] = 'Beheer tags';
$lang['Members'] = 'Leden';
$lang['Metadata synchronized from file'] = 'Metadata gesynchroniseerd van een bestand';
$lang['Move albums'] = 'Verplaats categorie';
$lang['Move'] = 'Verplaatsen';
$lang['Name'] = 'Naam';
$lang['New name'] = 'Nieuwe naam';
$lang['New parent album'] = 'Nieuwe hoofdcategorie';
$lang['New tag'] = 'Nieuwe tag';
$lang['Number of comments per page'] = 'Aantal weer te geven commentaren per pagina';
$lang['Number of rates'] = 'Aantal waarderingen';
$lang['Number of thumbnails to create'] = 'Aantal mini-afbeeldingen om te maken';
$lang['Only private albums are listed'] = 'Alleen privé categorieën worden getoond';
$lang['Operating system'] = 'Besturingssysteem';
$lang['Options'] = 'Opties';
$lang['Other private albums'] = 'Andere privé categorieën';
$lang['Page banner'] = 'Pagina banner';
$lang['Parent album'] = 'Hoofdcategorie';
$lang['Path'] = 'Pad';
$lang['Permalink'] = 'Permalink';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Permalink %s is eerder gebruikt door categorie %s. Verwijder de permalink geschiedenis eerst';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'De permalinknaam moet bestaan uit a-z, A-Z, 0-9, "-" of "_". Het mag geen getal zijn of starten met een "-"';
$lang['Permalink %s is already used by album %s'] = 'Permalink %s is al in gebruik door categorie %s';
$lang['Permalink history'] = 'Permalink geschiedenis';
$lang['Permalinks'] = 'Permalinks';
$lang['Permission denied'] = 'Toegang gewijgerd';
$lang['Permission granted thanks to a group'] = 'Rechten toegekend door een groep';
$lang['Permission granted'] = 'Toegang toegestaan';
$lang['Photo informations updated'] = 'Afbeeldings-informatie bijgewerkt';
$lang['Plugins'] = 'Plugins';
$lang['Position'] = 'Positie';
$lang['Preferences'] = 'Voorkeuren';
$lang['Properties'] = 'Eigenschappen';
$lang['Random photo'] = 'Willekeurig plaatje';
$lang['Rate date'] = 'Waarderingsdatum';
$lang['Rating by guests'] = 'Ook gasten kunnen waarderen';
$lang['Rating'] = 'Waardering';
$lang['Reject'] = 'Afwijzen';
$lang['Representant'] = 'Representant';
$lang['Representation of albums'] = 'Representatieve categorieën';
$lang['Representative'] = 'Representatief';
$lang['Represents'] = 'Representeerd';
$lang['Save order'] = 'Bewaar sortering';
$lang['Save to permalink history'] = 'Opslaan in permalink geschiedenis';
$lang['Select at least one album'] = 'Selecteer minstens één categorie';
$lang['Select at least one photo'] = 'Selecteer minstens één plaatje';
$lang['Select at least one user'] = 'Selecteer minstens één gebruiker';
$lang['Show info'] = 'Toon info';
$lang['Site manager'] = 'Site manager';
$lang['Status'] = 'Status';
$lang['Statistics'] = 'Statistieken';
$lang['Storage album'] = 'Opslag categorie';
$lang['Sum of rates'] = 'Eindwaardering';
$lang['Tag "%s" already exists'] = 'Tag "%s" bestaat al';
$lang['Tag "%s" was added'] = 'Tag "%s" is toegevoegd';
$lang['Tag selection'] = 'Tag selectie';
$lang['The %d following tags were deleted'] = 'De %d volgende tags zijn verwijderd';
$lang['Unable to check for upgrade.'] = 'Het is niet mogelijk om een upgradecontrole uit te voeren.';
$lang['Uninstall'] = 'Deinstaleer';
$lang['Use the default photo sort order (defined in the configuration file)']='Gebruik de standaard sortering (gedefinieerd in het configuratiebestand)';
$lang['User comments validation'] = 'Gebruikers-commentaren die wachten op validatie';
$lang['Users'] = 'Gebruikers';
$lang['Validate'] = 'Valideren';
$lang['Validation'] = 'Validatie van commentaar voor plaatsing is nodig';
$lang['Version'] = 'Versie';
$lang['Virtual albums to move'] = 'Virtuele categorieën om te verplaatsen';
$lang['Virtual album name'] = 'Virtuele categorienaam';
$lang['Webmaster cannot be deleted'] = 'Webbeheerder kan niet verwijderd worden';
$lang['You are running on development sources, no check possible.'] = 'U werkt op basis van ontwikkelings bronnen, geen controle mogelijk.';
$lang['You cannot delete your account'] = "U kunt uw account niet verwijderen";
$lang['You cannot move an album in its own sub album'] = 'U kunt een categorie niet verplaatsen naar zijn eigen sub-categorie';
$lang['You need to confirm deletion'] = 'U moet de verwijdering bevestigen';
$lang['add tags'] = 'Toevoegen tags';
$lang['Associate to album'] = 'Link aan categorie';
$lang['associate to group'] = 'Link aan groep';
$lang['Authorized'] = 'Toegestaan';
$lang['Add a virtual album'] = 'Voeg een virtuele categorie toe';
$lang['Authorize users to add comments on selected albums'] = 'Selecteer categorieën waarop commentaar gegeven mag worden';
$lang['The name of an album must not be empty'] = 'De naam van een categorie mag niet leeg zijn';
$lang['Lock albums'] = 'Beschikbaarheid van geselecteerde categorieën';
$lang['Private'] = 'Privé categorie';
$lang['Public'] = 'Openbare categorie';
$lang['Find a new representant by random'] = 'Vindt een willekeurige nieuwe representant';
$lang['Public / Private'] = 'Openbaar / Privé';
$lang['Manage authorizations for selected albums'] = 'Beheer toegang voor geselecteerde categorieën';
$lang['Virtual album added'] = 'Virtuele categorie toegevoegd';
$lang['Virtual album deleted'] = 'Virtuele categorie verwijderd';
$lang['Access type'] = 'Toegangstype';
$lang['Comments'] = 'Commentaar';
$lang['Information data registered in database'] = 'Informatie opgeslagen in de database';
$lang['Default display'] = 'Standaardweergave';
$lang['The gallery URL is not valid.'] = 'De URL van de galerie is niet correct.';
$lang['Main'] = 'Index';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Het aantal commentaren moet tussen 5 and 50 liggen.';
$lang['Configuration'] = 'Configuratie';
$lang['confirm'] = 'Bevestig';
$lang['Date'] = 'Datum';
$lang['delete album'] = 'verwijder categorie';
$lang['Dissociate from album'] = 'Verwijder link aan categorie';
$lang['dissociate from group'] = 'Verwijder link aan groep';
$lang['edit album permissions'] = 'bewerk categorie rechten';
$lang['Album updated successfully'] = 'Categorie informatie is met succes bijgewerkt.';
$lang['photos per page'] = 'Afbeeldingen per pagina';
$lang['High definition enabled'] = 'Hoge kwaliteit ingeschakeld';
$lang['File'] = 'Bestand';
$lang['Filesize'] = 'Bestandsgrootte';
$lang['first photo added on %s'] = 'eerste afbeelding toegevoegd op %s';
$lang['Forbidden'] = 'Niet toegestaan';
$lang['global mode'] = 'Compact overzicht';
$lang['group "%s" added'] = 'groep "%s" toegevoegd';
$lang['group "%s" deleted'] = 'groep "%s" verwijderd';
$lang['group "%s" updated'] = 'groep "%s" bijgewerkt';
$lang['group'] = 'Groep';
$lang['The name of a group must not contain " or \' or be empty.'] = 'De naam van de groep mag geen spatie bevatten of leeg zijn.';
$lang['This name is already used by another group.'] = 'Deze naam is al in gebruik door een andere groep.';
$lang['High definition'] = 'Hoge kwaliteit';
$lang['jump to album'] = 'Ga naar categorie';
$lang['jump to photo'] = 'Ga naar afbeelding';
$lang['leave'] = 'Niet wijzigen';
$lang['Lock'] = 'Gesloten';
$lang['Locked'] = 'Gesloten categorie';
$lang['manage album photos'] = 'Beheer categorie-afbeeldingen';
$lang['manage sub-albums'] = 'Beheer sub-categorie';
$lang['Manage'] = 'Beheer';
$lang['maximum height'] = 'maximale hoogte';
$lang['maximum width'] = 'maximale breedte';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Executie tijd is om, afhandeling moet verder gaan [Verwachte tijd: %d seconden].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Verwachte tijd voor de gebruikerslijst voor een mailing is gelimiteerd. Andere gebruikers staan niet op de lijst.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Tijd om email te sturen is gelimiteerd. Andere emailtjes worden overgeslagen.';
$lang['To send ?'] = 'aan sturen ?';
$lang['Last send'] = 'Laatst sturen';
$lang['email'] = 'email';
$lang['User'] = 'Gebruiker';
$lang['Complementary mail content'] = 'Inhoud email';
$lang['See you soon,'] = 'Tot ziens op onze webpagina,';
$lang['Go to'] = 'Ga naar ';
$lang['Hello'] = 'Hallo ';
$lang['New photos were added'] = 'Nieuwe afbeeldingen toegevoegd ';
$lang['on'] = ' op ';
$lang['between'] = 'tussen ';
$lang['and'] = ' en ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'De webbeheerder heeft u ingeschreven op de lijst om meldingen per email te ontvangen.';
$lang['You have subscribed to receiving notifications by mail.'] = 'U heeeft zich ingeschreven voor meldingen per email.';
$lang['To subscribe'] = 'Inschrijven';
$lang['If you encounter problems or have any question, please send a message to'] = 'Als u problemen of vragen heeft, stuur een bericht naar: ';
$lang['[NBM] Problems or questions'] = '[NBM] Problemen of vragen';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'De webbeheerder heeft u uitgeschreven van de meldingenlijst, u ontvangt geen meldingen meer per email.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'U heeft zichzelf uitgeschreven om meldingen per email te ontvangen.';
$lang[', click on'] = ', Klik op ';
$lang['To unsubscribe'] = 'Uitschrijven';
$lang['With blank value, gallery title will be used'] = 'Wanneer niet ingevuld, zal de galerie-titel worden gebruikt';
$lang['Notification'] = 'Meldingen';
$lang['Error when sending email to %s [%s].'] = 'Fout bij het versturen van email naar %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Email verstuuurd naar %s [%s].';
$lang['%d mail was sent.'] = '%d email is verstuurd.';
$lang['%d mails were sent.'] = '%d emails zijn verstuurd.';
$lang['%d mail was not sent.'] = '%d email is niet verstuurd.';
$lang['%d mails were not sent.'] = '%d emails zijn niet verstuurd.';
$lang['No mail to send.'] = 'Geen email om te versturen.';
$lang['There is no available subscribers to mail.'] = 'Geen gebruikers om email te sturen.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Een gebruiker is beschikbaar, er zijn nieuwe afbeeldingen te melden.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Het is mogelijk dat er geen ingeschreven gebruikers zijn (alleen de webbeheerder kan deze tab zien).';
$lang['No user to send notifications by mail.'] = 'Geen gebruikers om meldingen te versturen per email.';
$lang['New photos added'] = 'Nieuwe afbeeldingen toegevoegd';
$lang['Subscribe to notification by mail'] = 'Inschrijving om meldingen te ontvangen per email';
$lang['Unsubscribe from notification by mail'] = 'Uitschrijven van meldingen per email';
$lang['Parameter'] = 'Parameters';
$lang['Continue processing treatment'] = 'Verder gaan met de bewerking';
$lang['Complementary mail content'] = 'Bijkomende email-inhoud';
$lang['Add detailed content'] = 'Toevoegen gedetailleerde inhoud';
$lang['Send mail as'] = 'Stuur email als (afzender)';
$lang['Send mail to users'] = 'Stuur email naar gebruikers';
$lang['Send'] = 'Sturen';
$lang['Options'] = 'Opties';
$lang['Subscribed'] = 'Ingeschreven';
$lang['Subscribe'] = 'Inschrijven';
$lang['Parameters'] = 'Parameters';
$lang['Select recipients'] = 'Selecteer ontvangers';
$lang['Subscribe/unsubscribe users'] = 'Inschrijven/Uitschrijven gebruikers';
$lang['Unsubscribed'] = 'Uitgeschreven';
$lang['%d parameter was updated.'] = '%d parameter is bijgewerkt.';
$lang['%d parameters were updated.'] = '%d parameters zijn bijgewerkt.';
$lang['%d user was not updated.'] = '%d gebruiker is niet bijgewerkt.';
$lang['%d users were not updated.'] = '%d gebruikers zijn niet bijgewerkt.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Gebruiker %s [%s] is verwijderd van de inschrijvingslijst.';
$lang['User %s [%s] was added to the subscription list.'] = 'Gebruiker %s [%s] is toegevoegd aan de inschrijvingslijst.';
$lang['%d user was updated.'] = '%d gebruiker is bijgewerkt.';
$lang['%d users were updated.'] = '%d gebruikers zijn bijgewerkt.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Gebruiker %s [%s] is niet verwijderd van de inschrijvingslijst.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Gebruiker %s [%s] is niet toegevoegd aan de inschrijvingslijst.';
$lang['User %s [%s] added.'] = 'Gebruiker %s [%s] toegevoegd.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Waarschuwing: in/uitschrijven zal een email versturen naar de gebruiker';
$lang['Send mail on HTML format'] = 'Stuur email in HTML formaat';
$lang['Include display of recent photos grouped by dates'] = 'Inclusief tonen van recente afbeeldingen op basis van datum';
$lang['Available only with HTML format'] = 'Alleen beschikbaar in HTML formaat';
$lang['no write access'] = 'geen schrijftoegang';
$lang['Permissions'] = 'Rechten';
$lang['private'] = 'Privé';
$lang['public'] = 'Publiek';
$lang['Purge never used notification feeds'] = 'Verwijder nooit gebruikte meldingen';
$lang['Purge sessions'] = 'Verwijder sessies';
$lang['randomly represented'] = 'willekeurig gerepresenteerd';
$lang['registration date'] = 'Registratiedatum';
$lang['clean'] = 'opschonen';
$lang['remove remote listing.xml file'] = 'verwijder remote listing.xml bestand';
$lang['generate listing'] = 'genereer lijsten';
$lang['generate file listing.xml on remote site'] = 'genereer bestand listing.xml op remote site';
$lang['Create this site'] = 'maak deze site';
$lang['A local listing.xml file has been found for'] = 'Een lokale listing.xml bestand is gevonden voor ';
$lang['read local listing.xml and update'] = 'lees locale listing.xml en werk bij';
$lang['test'] = 'test';
$lang['test this remote site'] = 'test deze remote site';
$lang['remove tags'] = 'Verwijder tags';
$lang['Repair and optimize database'] = 'Repareer en optimaliseer de database';
$lang['selection'] = 'Selectie';
$lang['set to'] = 'Instellen op';
$lang['singly represented'] = 'afzonderlijk vertegenwoordigd';
$lang['This site already exists'] = 'Deze site bestaat al';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Maak een nieuwe site : (geef de URL naar bestand create_listing_file.php)';
$lang['created'] = 'gemaakt';
$lang['delete'] = 'Verwijderen';
$lang['delete this site and all its attached elements'] = 'Verwijder de site en alle bijbehorende afbeeldingen';
$lang['an error happened'] = 'er heeft zich een fout voorgedaan';
$lang['file create_listing_file.php on remote site was not found'] = 'Bestand create_listing_file.php werd niet op de remote site gevonden';
$lang['Local'] = 'Lokaal';
$lang['Remote'] = 'Remote';
$lang['synchronize'] = 'synchroniseer';
$lang['update the database from files'] = 'werk de database bij vanuit bestanden';
$lang['status'] = 'Status';
$lang['Directory'] = 'Map';
$lang['sub-albums'] = 'Sub-categorie';
$lang['synchronize metadata'] = 'synchroniseer metadata';
$lang['target'] = 'Doel';
$lang['Thumbnail'] = 'Mini-afbeelding';
$lang['title'] = 'Titel';
$lang['Album list management'] = 'Categorie beheer';
$lang['Piwigo configuration'] = 'Piwigo configuratie';
$lang['Edit album'] = 'Bewerk een categorie';
$lang['Group management'] = 'Groepsbeheer';
$lang['User list'] = 'Gebruikerslijst';
$lang['Edit photo information'] = 'Verander de informatie van een plaatje';
$lang['Thumbnail creation'] = 'Mini-afbeeldingen maken';
$lang['Database synchronization with files'] = 'Database synchronisatie met bestanden';
$lang['all'] = 'Allen';
$lang['photos without thumbnail (jpeg and png only)'] = 'afbeeldingen zonder mini-afbeelding (alleen jpeg en png)';
$lang['height must be a number superior to'] = 'Hoogte moet groter zijn dan';
$lang['width must be a number superior to'] = 'Breedte moet groter zijn dan';
$lang['for the file format'] = 'voor het bestandsformaat';
$lang['No missing thumbnail'] = 'Geen ontbrekende mini-afbeelding';
$lang['Photo unreachable or no support'] = 'Afbeelding is niet bereikbaar of er is geen support';
$lang['GD version'] = 'GD versie';
$lang['Miniaturization parameters'] = 'Miniatuur parameters';
$lang['generated in'] = 'gegenereerd in';
$lang['Results of miniaturization'] = 'Resultaat van verkleinen';
$lang['General statistics'] = 'Algemene statistieken';
$lang['max time'] = 'maximale tijd';
$lang['average time'] = 'gemiddelde tijd';
$lang['min time'] = 'minimale tijd';
$lang['number of miniaturized photos'] = 'aantal verkleinde afbeeldingen';
$lang['total time'] = 'totale tijd';
$lang['for this file format'] = 'voor dit bestandsformaat';
$lang['unit mode'] = 'Uitgebreid overzicht';
$lang['Unlocked'] = 'Open categorie';
$lang['unset'] = 'Niet ingesteld';
$lang['Update albums informations'] = 'Categorie-informatie bijwerken';
$lang['Update photos information'] = 'Afbeeldings-informatie bijwerken';
$lang['Synchronize'] = 'Synchroniseer';
$lang['reduce to single existing albums'] = 'Alleen naar de bestaande categorieën terugbrengen';
$lang['Choose an option'] = 'Kies een optie';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'toon maximale informatie (toegevoegde categorieën en afbeeldingen, verwijderde categorieën en afbeeldingen)';
$lang['Piwigo version differs on the remote site'] = 'Piwigo versie verschilt op de remote site';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Versie van create_listing_file.php op de remote site en Piwigo moeten gelijk zijn';
$lang['listing.xml file was not found'] = 'listing.xml file is niet gevonden';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'listing.xml file is niet gevonden op de remote site. Het bestand word gegenereerd door het commando "genereer listing" in de Site manager';
$lang['Error list'] = 'Foutenlijst';
$lang['Errors caption'] = 'Foutmeldingen afvangen';
$lang['Detailed informations'] = 'Gedetailleerde informatie';
$lang['File/directory read error'] = 'Bestand/map lees fout';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Het bestand of map kan niet worden benaderd (of het bestand of map bestaat niet of heeft geen rechten)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Een afbeelding heeft een mini-afbeelding nodig. De mini-afbeelding moet in de subdirectorie "thumbnail" van de betreffende categorie aanwezig zijn. De mini-afbeelding moet starten met het in de configuratie opgegeven voorvoegsel (prefix) en mag alleen een extentie bevatten die voorkomt in de volgende lijst:';
$lang['missing thumbnail'] = 'ontbrekende mini-afbeelding';
$lang['albums deleted in the database'] = 'categorieën verwijderd uit de database';
$lang['photos deleted from the database'] = 'afbeeldingen verwijderd uit de database';
$lang['photos candidates for metadata synchronization'] = 'afbeeldingen gesynchroniseerd met de metadata van de bijbehorende bestanden';
$lang['photos informations synchronized with files metadata'] = 'afbeeldings-informatie gesynchroniseerd met bestandsmetadata';
$lang['errors during synchronization'] = 'fouten tijdens synchronisatie';
$lang['albums added in the database'] = 'categorieën toegevoegd aan de database';
$lang['photos added in the database'] = 'afbeeldingen toegevoegd aan de database';
$lang['photos updated in the database'] = 'afbeeldingen bijgewerkt in de database';
$lang['Search for new images in the directories'] = 'Zoek naar nieuwe afbeeldingen in mappen';
$lang['added'] = 'toegevoegd';
$lang['deleted'] = 'verwijderd';
$lang['Metadata synchronization results'] = 'Metadata synchronisatie resultaten';
$lang['only perform a simulation (no change in database will be made)'] = 'alleen een simulatie uitvoeren (er worden geen veranderingen aangebracht in de database)';
$lang['[Simulation]'] = '[Simulatie]';
$lang['Simulation'] = 'Simulatie';
$lang['directories + files'] = 'mappen + bestanden';
$lang['only directories'] = 'alleen mappen';
$lang['synchronize files structure with database'] = 'Synchroniseer bestanden met de database';
$lang['synchronize files metadata with database photos informations'] = 'Synchroniseer bestandsmetadata met de database afbeeldings-informatie';
$lang['even already synchronized photos'] = 'ook reeds synchroniseerde afbeeldingen';
$lang['Used metadata'] = 'Gebruikte metadata';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'De naam van de mappen en bestanden moeten bestaan uit letters, "-", "_" of "."';
$lang['wrong filename'] = 'verkeerde bestandsnaam';
$lang['Upload'] = 'Upload';
$lang['user "%s" added'] = 'gebruiker "%s" toegevoegd';
$lang['User status'] = 'Gebruikersstatus';
$lang['user_status_admin'] = 'Beheerder';
$lang['user_status_generic'] = 'Algemeen';
$lang['user_status_guest'] = 'Gast';
$lang['user_status_normal'] = 'Gebruiker';
$lang['user_status_webmaster'] = 'Webbeheerder';
$lang['Virtual album'] = 'Virtuele categorieën';
$lang['Waiting'] = 'Valideer';
$lang['default'] = 'standaard';
$lang['Toggle \'default group\' property'] = 'Wissel \'standaard groep\' instelling';
$lang['Advanced features'] = 'Geavanceerde functies';
$lang['Specials'] = 'Speciaal';
$lang['Overall'] = 'Totaal';
$lang['Year'] = 'Jaar';
$lang['Month'] = 'Maand';
$lang['Day'] = 'Dag';
$lang['Pages seen'] = 'Pagina\'s bekeken';
$lang['Time'] = 'tijd';
$lang['IP'] = 'IP';
$lang['Element'] = '';
$lang['Section'] = 'sectie';
$lang['Tags'] = 'Tags';
$lang['Save page visits by guests'] = 'Bewaar geschiedenis van pagina-bezoek van gasten';
$lang['Save page visits by users'] = 'Bewaar geschiedenis van pagina-bezoek van gebruikers';
$lang['Save page visits by administrators'] = 'Bewaar geschiedenis van pagina-bezoek van beheerders';
$lang['An information email was sent to group "%s"'] = 'Een informatie email is verstuurd naar de groep "%s"';
$lang['Send an information email to group members'] = 'Stuur een informatie email naar groepsleden';
$lang['Group'] = 'Groep';
$lang['[%s] Visit album %s'] = '[%s] Bezoek de categorie %s';
$lang['Hello,'] = 'Hallo,';
$lang['See you soon.'] = 'Tot ziens op onze webpagina.';
$lang['Discover album:'] = 'Ondek de categorie:';
$lang['Mail content'] = 'Email inhoud';
$lang['none'] = 'geen';
$lang['high'] = 'hoog';
$lang['other'] = 'anders';
$lang['Element type'] = 'afbeeldings-type';
$lang['Image id'] = 'Afbeeldings id';
$lang['Summary'] = 'Overzicht';
$lang['%d line filtered'] = '%d regel gefilterd';
$lang['%d lines filtered'] = '%d regels filterd';
$lang['%d guest'] = '%d gast';
$lang['%d guests'] = '%d gasten';
$lang['Hour'] = 'Uur';
$lang['guest'] = 'gast';
$lang['default values'] = 'Standaard waarden';
$lang['High filesize'] = 'Grootte bestandsformaat';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Gast kan niet verwijderd worden';
$lang['Default user cannot be deleted'] = 'Standaard gebruiker kan niet verwijderd worden';
$lang['Purge history detail'] = 'Details van de filtergeschiedenis';
$lang['Purge history summary'] = 'Overzicht van de filtergeschiedenis';
$lang['Check integrity'] = 'Controleer integriteit';
$lang['Anomaly'] = 'Onregelmatigheid';
$lang['Correction'] = 'Correctie';
$lang['Automatic correction'] = 'Automatische correctie';
$lang['Impossible automatic correction'] = 'Onmogelijke automatische correctie';
$lang['Correction applied with success'] = 'Correctie die met succes is toegepast';
$lang['Correction applied with error'] = 'Correctie die met fout wordt toegepast';
$lang['%d anomaly has been detected.'] = '%d Onregelmatigheid ontdekt.';
$lang['%d anomalies have been detected.'] = '%d Onregelmatigheden ontdekt.';
$lang['%d anomaly has been corrected.'] = '%d Onregelmatigheid is gecorrigeerd.';
$lang['%d anomalies have been detected corrected.'] = '%d Onregelmatigheden die zijn gecorrigeerd.';
$lang['%d anomaly has not been corrected.'] = '%d Onregelmatigheid ontdekt is niet gecorrigeerd.';
$lang['%d anomalies have not been corrected.'] = '%d Onregelmatigheden zijn niet gecorrigeerd.';
$lang['Go to %s or %s for more informations'] = 'Ga naar %s of %s voor meer informatie';
$lang['the forum'] = 'het forum';
$lang['the wiki'] = 'de wiki';
$lang['%s value is not correct file because exif are not supported'] = '%s waarde is niet een correct bestand omdat exif niet ondersteund wordt';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s moet aangepast worden naar false in uw local/config/config.inc.php bestand';
$lang['Main "guest" user does not exist'] = 'Hoofd "gast" gebruiker bestaat niet meer';
$lang['Main "guest" user status is incorrect'] = 'Hoofd "gast" gebruikersstatus is niet correct';
$lang['Default user does not exist'] = 'Standaard gebruiker bestaat niet meer';
$lang['Main "webmaster" user does not exist'] = 'Hoofd "webbeheerder" bestaat niet meer';
$lang['Main "webmaster" user status is incorrect'] = 'Hoofd "webbeheerder" status is niet correct';
$lang['User "%s" created with "%s" like password'] = 'Gebruiker "%s" gemaakt met wachtwoord "%s" ';
$lang['Status of user "%s" updated'] = 'Status van de gebruiker "%s" is bijgewerkt';
$lang['add new photos to caddie'] = 'voeg nieuwe afbeeldingen toe aan winkelmandje';
$lang['No display'] = 'Geen weergave';
$lang['Classic display'] = 'Klassieke weergave';
$lang['Hoverbox display'] = 'Hoverbox weergave';
$lang['Mail address is obligatory for all users'] = 'Email-adres is verplicht voor alle gebruikers';
$lang['Minimum privacy level'] = 'Minimaal privacy nivo';
$lang['Privacy level'] = 'Privacy nivo';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Contacten';
$lang['Level 2'] = 'Vrienden';
$lang['Level 4'] = 'Familie';
$lang['Level 8'] = 'Admins';
$lang['Reinitialize check integrity'] = 'Herinitialiseer de integriteitscontrole';
$lang['Check all'] = 'Selecteer alles';
$lang['Uncheck all'] = 'Deselecteer alles';
$lang['Check automatic corrections'] = 'Controleer de aoutomatische correcties';
$lang['Apply selected corrections'] = 'Pas geselecteerde correcties toe';
$lang['Ignore selected anomalies'] = 'Negeer geselecteerde onregelmatigheden';
$lang['Refresh'] = 'Ververs';
$lang['The anomaly will be ignored until next application version'] = 'De onregelmatigheid wordt genegeerd tot de volgende versie';
$lang['%d anomaly has been ignored.'] = '%d onregelmatigheid wordt genegeerd.';
$lang['%d anomalies have been ignored.'] = '%d onregelmatigheden worden genegeerd.';
$lang['Plugins which need upgrade'] = 'Plugins welke bijgewerkt moeten worden';
$lang['Plugin list'] = 'Plugin lijst';
$lang['Check for updates'] = 'Controleer op updates';
$lang['Other plugins'] = 'Andere plugins';
$lang['Last revisions'] = 'Lastste revisie';
$lang['Delete'] = 'Verwijder';
$lang['Are you sure you want to delete this plugin?'] = 'Weet U het zeker dat u deze plugin wilt verwijderen?';
$lang['Are you sure you want to install this plugin?'] = 'Weet U het zeker dat u deze plugin wilt installeren?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Weet U het zeker dat u deze plugin wilt bijwerken? U moet controleren of deze versie niet gedeinstaleerd moet worden.';
$lang['%s has been successfully upgraded.'] = '%s zijn succesvol bijgewerkt.';
$lang['Plugin has been successfully copied'] = 'Plugin is succesvol gekopieerd';
$lang['You might go to plugin list to install and activate it.'] = 'U zou naar de plugin-lijst kunnen gaan om de plugin te installeren en te activeren.';
$lang['Can\'t create temporary file.'] = 'Kan geen tijdelijk bestand maken.';
$lang['Can\'t download archive.'] = 'Kan geen archief downloaden.';
$lang['Can\'t read or extract archive.'] = 'Kan het archief niet lezen of uitpakken.';
$lang['An error occured during extraction (%s).'] = 'Een fout is opgetreden tijdens het uitpakken (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Controleer de "plugins" folder en de sub-folders permissies (CHMOD).';
$lang['Can\'t connect to server.'] = 'Kan niet met de server verbinden.';
$lang['Purge compiled templates'] = 'Verwijder samengestelde sjablonen';
$lang['Support'] = 'Piwigo Forum';
$lang['Documentation'] = 'Documentatie';
$lang['ACCESS_0'] = 'Vrije toegang';
$lang['ACCESS_1'] = 'Toegang tot alles';
$lang['ACCESS_2'] = 'Toegang tot geabonneerde';
$lang['ACCESS_3'] = 'Toegang voor beheerders';
$lang['ACCESS_4'] = 'Toegang voor webbeheerders';
$lang['ACCESS_5'] = 'Geen toegang';
$lang['A new version of Piwigo is available.'] = 'Een nieuwere versie van Piwigo is beschikbaar.';
$lang['Piwigo Administration'] = 'Piwigo Beheer';
$lang['Piwigo version'] = 'Piwigo versie';
$lang['You are running the latest version of Piwigo.'] = 'U heeft de laatste versie van Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'De versie van %s [%s] die geïnstalleerd is is niet compatibel met de vereiste versie [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'U moet uw systeem bijwerken om volledig gebruik te kunnen maken van alle mogelijkheden van de software, anders kan de software niet goed werken, of helemaal niet';
$lang['Deleted on'] = 'Verwijderd op';
$lang['Last hit'] =  'Laaste hit';
$lang['GD library is missing'] = 'GD library bestaat niet';
$lang['Templates'] = 'Sjablonen';
$lang['Extend for templates'] = 'Uitbreiding voor sjablonen';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 
 'Vervanging van de originele sjablonen door aangepaste sjablonen van sjabloon-extensie submap';
$lang['Replacers (customized templates)'] = 'Vervangers (eigenbouw sjabloon)';
$lang['Original templates'] = 'Originele sjabloontemplates';
$lang['Optional URL keyword'] = 'Optionele URL sleutelwoord';
$lang['Templates configuration has been recorded.'] = 'Sjabloon configuratie is vastgelegd.';
$lang['All optimizations have been successfully completed.'] = 'Alle verbeteringen zijn succesvol afgerond.';
$lang['Optimizations have been completed with some errors.'] = 'Verbeteringen zijn afgerond met enkele fouten.';
$lang['Modify information'] = 'Aanpassen informatie';
$lang['edit album'] = 'Bewerk categorie-informatie';
$lang['nothing'] = 'niets';
$lang['overrides existing values with empty ones'] = 'overschrijft de bestaande waarden met lege waardes';
$lang['Drag to re-order'] = 'Sleep om volgorde te veranderen';
$lang['Quick Local Synchronization'] = 'Snelle lokale Synchronisatie';
$lang['No photo can be deleted'] = 'Geen enkele foto kan verwijderd worden';
$lang['Delete selected photos'] = 'Verwijder geselecteerde foto\'s';
$lang['%d photo was deleted'] = '%d foto is verwijderd';
$lang['%d photos were deleted'] = '%d foto\'s zijn verwijderd';
$lang['Downloads'] = 'Downloads';
$lang['Released on'] = 'Uitgegeven op';
$lang['Number of downloads'] = 'Aantal downloads';
// --------- Starting below: New or revised $lang ---- from Colibri
$lang['Operation in progress'] = 'In behandeling.';
$lang['Please wait...'] = 'Even geduld aub...';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Het corrigeren van de onregelmatigheid maakt een einde aan het negeren';
$lang['manage photo ranks'] = 'bewerk de afbeeldingsrangen';
$lang['Manage photo ranks'] = 'Bewerk de afbeeldingsrangen';
$lang['Edit ranks'] = 'Bewerk de rangen';
$lang['No photo in this album'] = 'Geen element in deze categorie';
$lang['Images manual order was saved'] = 'De handmatige sortering van de afbeeldingen is bewaard';
$lang['ranks'] = 'Rangen';
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Aankondigings Nieuwsbrief';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Hou contact met het Piwigo project, abonneer u op de Piwigo Aankondigings Nieuwsbrief. Dan ontvangt u een email wanneer een nieuwe Piwigo-release beschikbaar komt, wanneer een belangrijke beveiligings bugfix nodig is of wanneer belangrijke ontwikkelingen binnen het Piwigo-project plaatsvinden. Alles bij elkaar een paar emails per jaar.';
$lang['Subscribe %s'] = 'Abonneer %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Abonneer %s op de Piwigo Aankondigings Nieuwsbrief';
$lang['Purge search history'] = 'Verwijder de Zoek-geschiedenis';
$lang['Hide'] = 'Verberg';
$lang['Password is missing. Please enter the password.'] = 'Wachtwoord ontbreekt. Geef uw wachtwoord aub.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Wachtwoord-bevestiging ontbreekt. Bevestig aub uw gekozen wachtwoord.';
$lang['Password confirmation error.'] = 'Fout bij de wachtwoord-bevestiging.';
$lang['Allow users to edit their own comments'] = 'Sta toe dat gebruikers hun eigen commentaar kunnen bewerken';
$lang['Allow users to delete their own comments'] = 'Sta toe dat gebruikers hun eigen comentaar kunnen verwijderen';
$lang['Email administrators when a comment is modified'] = 'Stuur email naar de administrators wanneer een commentaar is gewijzigd';
$lang['Email administrators when a comment is deleted'] = 'Stuur email naar de administrators wanneer een commentaar is verwijderd';
$lang['Cannot delete the old permalink !'] = 'De oude permalink kan niet verwijderd worden !';
$lang['Hit'] = 'Hit';
$lang['Tools'] = 'Hulpmiddelen';
$lang['Photos'] = 'Foto\'s';
$lang['Themes'] = 'Thema\'s';
$lang['Instructions to use Piwigo'] = 'Piwigo Gebruiks-instructies';
$lang['Installed Themes'] = 'Geïnstalleerde thema\'s';
$lang['Add New Theme'] = 'Nog niet geïnstaleerde thema\'s';
$lang['Forbid this theme to users'] = 'Dit thema mag niet door gebruikers gebruikt worden';
$lang['Set as default theme for unregistered and new users'] = 'Standaard thema voor niet geregisteerde and nieuwe gebruikers';
$lang['unknown'] = 'onbekend';
$lang['Upload Photos'] = 'Upload Foto\'s';
$lang['Drop into album'] = 'Toevoegen aan categorie';
$lang['+ Add an upload box'] = 'Voeg een upload-fregel toe';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Maak de "%s" directory aan vanuit de root van uw Piwigo-installatie';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Geef schrijfrechten (chmod 777) aan de "%s" directory vanuit de root van uw piwigo installatie';
$lang['existing album'] = 'Bestaande categorie';
$lang['create a new album'] = 'Maak een nieuwe categorie aan';
$lang['Album name'] = 'Categorienaam';
$lang['Album "%s" has been added'] = 'Categorie "%s" is toegevoegd';
$lang['Uploaded Photos'] = 'Ge-uploade Foto\'s';
$lang['%d photos uploaded'] = '%d foto\'s ge-uploaded';
$lang['Privacy level set to "%s"'] = 'Privacy-niveau staat nu op "%s"';
$lang['Album "%s" now contains %d photos'] = 'Categorie "%s" bevat nu %d foto\'s';
$lang['Manage this set of %d photos'] = 'Beheer deze reeks van %d foto\'s';
$lang['Select files'] = 'Selecteer bestanden';
$lang['Everybody'] = 'Iedereen';
$lang['Who can see these photos?'] = 'Wie mag deze foto\'s zien?';
$lang['The websize maximum width must be a number between %d and %d'] = 'De webgrootte maximum breedte moet liggen tussen %d en %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'De webgrootte maximum hoogte moet liggen tussen %d en %d';
$lang['The websize image quality must be a number between %d and %d'] = 'De webgrootte afbeeldingskwaliteit moet liggen tussen %d en %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'De maximum breedte van de mini-afbeelding moet liggen tussen %d en %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'De maximimum hoogte van de mini-afbeelding moet liggen tussen %d en %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'De afbeeldingskwaliteit van de mini-afbeelding moet liggen tussen %d en %d';
$lang['Settings'] = 'Instellingen';
$lang['Web size photo'] = 'Webgrootte foto';
$lang['Resize'] = 'Grootte aanpassen';
$lang['Maximum Width'] = 'Maximum Breedte';
$lang['pixels'] = 'pixels';
$lang['Maximum Height'] = 'Maximum Hoogte';
$lang['Image Quality'] = 'Afbeeldingskwaliteit';
$lang['Save Settings'] = 'Bewaar instellingen';
$lang['Your configuration settings are saved'] = 'Uw configuratie-instellingen zijn opgeslagen';
$lang['Active Themes'] = 'Actieve Thema\'s';
$lang['Add write access to the "%s" directory'] = 'Geef de "%s" directorie schrijfbevoegdheden';
$lang['Administration Home'] = 'Administratie Startpagina';
$lang['Change Admin Colors'] = 'Wijzig de Admin-kleuren';
$lang['Delete this theme'] = 'Verwijder dit thema';
$lang['Directory does not exist'] = 'Directorie bestaat niet';
$lang['Download,'] = 'Download,';
$lang['FTP + Synchronization'] = 'FTP + Synchronisatie';
$lang['Get Support on Piwigo Forum'] = 'Zoek/Krijg ondersteuning op het Piwigo gebruikers-forum';
$lang['Help Me'] = 'Help';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Het is niet mogelijk dit thema te activeren, het basis-thema ontbreekt: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Het is niet mogelijk dit thema te verwijderen. Er zijn nog andere thema\'s die aan dit thema gekoppeld zijn: %s';
$lang['Inactive Themes'] = 'Niet actieve Thema\'s';
$lang['Install on your computer,'] = 'Installeer op uw computer,';
$lang['Make this theme available to users'] = 'Maak dit thema beschikbaar voor gebruikers';
$lang['Page end'] = 'Pagina-einde';
$lang['Piwigo Uploader'] = 'Piwigo Uploader';
$lang['Read Piwigo Documentation'] = 'Lees de Piwigo Documentatie';
$lang['Start pLoader and add your photos.'] = 'Start pLoader en voeg uw foto\'s toe.';
$lang['Switch to clear or dark colors for administration'] = 'Schakel om naar heldere of donkere kleuren voor de administratie';
$lang['Theme has been successfully installed'] = 'Thema is succesvol geïnstalleerd';
$lang['Visit Gallery'] = 'Bezoek Galerie';
$lang['Visit Piwigo project website'] = 'Bezoek de website van het Piwigo project';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader is een afkorting van <em>Piwigo Uploader</em>. pLoader maakt uw foto\'s op uw computer klaar en zet ze dan over naar uw Piwigo fotogalerie.';
$lang['Guest Settings'] = 'Bezoeker/Guest-Instellingen';
$lang['Main Page'] = 'Hoofd-pagina';
$lang['Photo Page'] = 'Foto-pagina';
$lang['Activate Navigation Bar'] = 'Activeer de Navigatie-balk';
$lang['Activate Navigation Thumbnails'] = 'Activeer de Navigatie-mini-afbeeldingen';
$lang['Activate icon "%s"'] = 'Activeer icoon "%s"';
$lang['Activate field "%s"'] = 'Activeer veld "%s"';
$lang['Photo Properties'] = 'Foto-Eigenschappen';
$lang['Allow user customization'] = 'Sta gebruikers-aanpassingen toe';
$lang['Languages'] = 'Talen';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Uitvoerings-tijd overschreden, de afhandeling moet verder gaan [Geschatte tijd: %d seconden].';
$lang['Installed Languages'] = 'Geïnstalleerde talen';
$lang['Add New Language'] = 'Voeg een nieuwe taal toe';
$lang['Language has been successfully installed'] = 'Taal is succesvol geïnstalleerd';
$lang['Select:'] = 'Selecteer:';
$lang['None'] = 'Geen';
$lang['Invert'] = 'Inverteer';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Dit thema kan niet gedeactiveerd worden. Er moet minstens één thema geactiveerd zijn.';
$lang['Webmaster status is required.'] = 'De status van de webbeheerder is noodzakelijk.';
$lang['Bound Theme'] = 'Gebonden Thema';
$lang['Allow rating'] = 'Waarderings-optie inschakelen';
$lang['Select at least one comment'] = 'Minstens een commentaar selecteren';
$lang['Active Plugins'] = 'Actieve Plugins';
$lang['Inactive Plugins'] = 'Niet actieve Plugins';
$lang['Missing Plugins'] = 'Missende Plugins';
$lang['Uninstalled Plugins'] = 'Niet geïnstalleerde Plugins';
$lang['By %s'] = 'Door %s';
$lang['Visit plugin site'] = 'Bezoek de plugin site';
$lang['Active Languages'] = 'Actieve talen';
$lang['Delete this language'] = 'Verwijder deze taal';
$lang['Forbid this language to users'] = 'Stel deze taal niet beschikbaar aan gebruikers';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Niet mogelijk om deze taal te deactiveren, stel eerst een andere taal in als standaardtaal.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Niet mogelijk om deze taal te deactiveren, er moet minstens één taal actief zijn.';
$lang['Inactive Languages'] = 'Niet actieve talen';
$lang['Make this language available to users'] = 'Stel deze taal beschikbaar aan gebruikers';
$lang['Set as default language for unregistered and new users'] = 'Stel in als standaardtaal voor niet geregistreerde en nieuwe gebruikers';
$lang['Miscellaneous'] = 'Diverse';
$lang['Virtual Links'] = 'Virtuele Links';
$lang['Add Photos'] = 'Afbeeldingen toevoegen';
$lang['Download'] = 'Download';
$lang['The following tag was deleted'] = 'De volgende tag werd verwijderd';
$lang['There is no other language available.'] = 'Er is geen andere taal beschikbaar.';
$lang['There is no other plugin available.'] = 'Er is geen andere plugin beschikbaar.';
$lang['There is no other theme available.'] = 'Er is geen andere thema beschikbaar.';
$lang['Add another set of photos'] = 'Een andere set afbeeldingen toevoegen';
$lang['By rank'] = 'Op rank';
$lang['Manual order'] = 'Handmatige volgorde';
$lang['Order of menubar items has been updated successfully.'] = 'De volgorde van menu-items is succesvol aangepast.';
$lang['This theme was not designed to be directly activated'] = 'Dit thema is niet ontworpen om direct geactiveerd te worden';
$lang['Who can see this photo?'] = 'Wie mag deze afbeelding zien?';
$lang['Pending Comments'] = 'Nog niet goedgekeurde commentaren';
$lang['Menu Management'] = 'Menu';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'In uw php.ini bestand, de upload_max_filesize (%sB) is groter dan post_max_size (%sB), moet u deze instelling wijzigen';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif extension not available, admin should disable exif use';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Het geuploade bestand is groter dan de upload_max_filesize richtlijn in php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Het geuploade bestand is groter dan de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier';
$lang['The uploaded file was only partially uploaded'] = 'Het geuploade bestand is slechts gedeeltelijk geupload';
$lang['No file was uploaded'] = 'Er is geen bestand geupload';
$lang['Missing a temporary folder'] = 'Er ontbreekt een tijdelijke map';
$lang['Failed to write file to disk'] = 'Kan bestand niet naar schijf schrijven';
$lang['File upload stopped by extension'] = 'Bestand upload gestopt door bestandsextensie';
$lang['Unknown upload error'] = 'Onbekende upload fout';
$lang['Error on file "%s" : %s'] = 'Fout in het bestand "%s" : %s';
$lang['automatic order'] = 'automatische volgorde';
$lang['manual order'] = 'handmatige volgorde';
$lang['Albums automatically sorted'] = 'Albums automatisch gesorteerd';
$lang['Keep high definition'] = 'Behoud hoge resolutie';
$lang['The high definition maximum width must be a number between %d and %d'] = 'De hoge resolutie maximale breedte moet een nummer zijn tussen %d en %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'De hoge resolutie maximale hoogte moet een getal zijn tussen %d en %d';
$lang['The high definition image quality must be a number between %d and %d'] = 'De hoge resolutie beeldkwaliteit moet een getal zijn tussen %d en %d';
$lang['Batch Manager'] = 'Bulk beheerder';
$lang['include child albums'] = 'include child albums';
$lang['Selection'] = 'Selectie';
$lang['Action'] = 'Actie';
$lang['Set author'] = 'Stel auteur in';
$lang['Set title'] = 'Stel titel in';
$lang['Set creation date'] = 'Stel aanmaakdatum in';
$lang['Apply action'] = 'Toepassen';
$lang['on the %d selected photos'] = 'op de %d geselecteerde foto\'s';
$lang['%d of %d photos selected'] = '%d van %d foto\'s geselecteerd';
$lang['No photo selected, %d photos in current set'] = 'Geen foto geselecteerd, %d foto\'s in de huidige set';
$lang['All %d photos are selected'] = 'Alle %d foto\'s zijn geselecteerd';
$lang['remove this filter'] = 'Verwijder dit filter';
$lang['predefined filter'] = 'vooraf gedefinieerd filter';
$lang['last import'] = 'Laatste import';
$lang['with no virtual album'] = 'zonder virtueel album';
$lang['duplicates'] = 'duplicaten';
$lang['Add a filter'] = 'Voeg een filter toe';
$lang['Remove all filters'] = 'Verwijder alle filters';
$lang['Refresh photo set'] = 'Vernieuwen foto set';
$lang['The whole page'] = 'De hele pagina';
$lang['The whole set'] = 'De hele set';
$lang['No photo in the current set.'] = 'Geen foto in de huidige reeks.';
$lang['No photo selected, no action possible.'] = 'Geen foto geselecteerd, geen actie mogelijk is.';
$lang['Choose an action'] = 'Kies een actie';
$lang['remove author'] = 'Verwijder auteur';
$lang['Type here the author name'] = 'Typ hier de naam van de auteur';
$lang['remove title'] = 'Verwijder titel';
$lang['Type here the title'] = 'Typ hier de titel';
$lang['remove creation date'] = 'verwijder aanmaakdatum';
$lang['with no album'] = 'zonder album';
$lang['with no tag'] = 'zonder tag';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif extensie is niet beschikbaar, de administrator moet exif gebruik uitsluiten';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Het geuploade bestand is groter dan upload_max_filesize instelling in php.ini: %sB';
$lang['include child albums'] = 'inclusief sub albums';
$lang['Album photos associated to the following albums: %s'] = 'Fotoalbums verbonden met de volgende albums: %s';
$lang['Delete orphan tags'] = 'Verwijder niet gebruikte labels';
$lang['delete photo'] = 'verwijder afbeelding';
$lang['Orphan tags deleted'] = 'Verwijderde niet gebruikte labels';
$lang['Remove from caddie'] = 'Verwijder uit winkelwagen';
$lang['Week starts on'] = 'De week begint op';
$lang['You have %d orphan tags: %s.'] = 'U heeft %d niet gebruikte labels: %s.';
$lang['Themes which need upgrade'] = 'Thema\'s die bijgewerkt moeten worden';
$lang['Languages which need upgrade'] = 'Talen die bijgewerkt moeten worden';
$lang['All themes are up to date.'] = 'Alle thema\'s zijn bijgewerkt.';
$lang['All plugins are up to date.'] = 'Alle plugins zijn bijgewerkt.';
$lang['All languages are up to date.'] = 'Alle talen zijn bijgewerkt.';
$lang['Visit theme site'] = 'Bezoek de thema-webpagina';
$lang['Visit language site'] = 'Bezoek de talen-webpagina';
$lang['New Version'] = 'Nieuwe versie';
$lang['Obsolete Plugins'] = 'Verouderde Plugins';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'WAARSCHUWING! Deze plugin lijkt niet compatibel met deze versie van Piwigo.';
$lang['Do you want to activate anyway?'] = 'Wilt u desondanks activeren?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'DEZE PLUGIN IS NU ONDERDEEL VAN PIWIGO CORE! VERWIJDER DE PLUGIN NU.';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'FOUT: DEZE PLUGIN MIST MAAR IS GEINSTALEERD! DEINSTALLEER DE PLUGIN NU.';
$lang['Regenerate Thumbnails'] = 'Hergenereer Thumbnails';
$lang['Thumbnails generation in progress...'] = 'Bezig met genereren van thumbnails...';
$lang['%s thumbnails have been regenerated'] = '%s thumbnails zijn opnieuw gegenereerd.';
$lang['%s thumbnails can not be regenerated'] = '%s thumbnails kunnen niet opnieuw worden gegenereerd.';
$lang['Regenerate Websize Photos'] = 'Hergenereer webformaat foto\'s.';
$lang['Photos generation in progress...'] = 'Bezig met hergenereren foto\'s...';
$lang['%s photos have been regenerated'] = '%s foto\'s zijn hergegenereerd.';
$lang['%s photos can not be regenerated'] = '%s foto\'s konden niet opnieuw gegenereerd worden.';
$lang['display'] = 'toon';
$lang['new'] = 'nieuw';
$lang['No results'] = 'Geen resultaten';
$lang['Searching...'] = 'Bezig met zoeken...';
$lang['Type in a search term'] = 'Type een zoekterm in';
$lang['Activate icon "new" next to albums and pictures'] = 'Activeer "nieuw" pictogram naast albums en afbeeldingen';
$lang['Deactivate all'] = 'Deactiveer alles';
$lang['Default photos order'] = 'Standaard foto volgorde';
$lang['Restore'] = 'Herstel';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Herstel de standaard instellingen. Je zal alle plugin instellingen kwijtraken!';
$lang['Show menubar'] = 'Toon menubalk';
$lang['Updates'] = 'Updates';
$lang['Update in progress... Please wait.'] = 'Bezig met updaten... Even geduld aub';
$lang['Ignore this update'] = 'Negeer deze update';
$lang['Reset ignored updates'] = 'Reset genegeerde updates';
$lang['Update All'] = 'Update Alles';
$lang['ERROR'] = 'ERROR';
$lang['Update Complete'] = 'Update klaar';
$lang['Piwigo Update'] = 'Piwigo Update';
$lang['Extensions Update'] = 'Uitbreidingen Update';
$lang['All extensions are up to date.'] = 'Alle uitbreidingen zijn bijgewerkt.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'De volgende plugins zouden niet compatibel kunnen zijn met de nieuwe versie van Piwigo:';
$lang['Add a criteria'] = 'Voeg een criterium toe';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'U kan geen standaard foto volgorde aanmaken, omdat u een aangepaste instelling in uw locale configuratie heeft.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'U heeft <i>$conf[\'order_by\']</i> in uw lokale configuratie bestand gespecificeerd. Deze parameter is verouderd, verwijder het of hernoem het naar <i>$conf[\'order_by_custom\']</i> !';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'De volgende thema\'s zijn mogelijk niet compatibel met de nieuwe versie van Piwigo:';
$lang['I decide to update anyway'] = 'Ik besluit om alsnog te updaten';
$lang['Update to Piwigo %s'] = 'Update naar Piwigo %s';
$lang['Two updates are available'] = 'Twee updates zijn beschikbaar';
$lang['This is a minor update, with only bug corrections.'] = 'Dit is een kleine update, met alleen wat gerepareerde foutjes.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Dit is een grote update, met <a href="%s">allerlei nieuwe mogelijkheden</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Sommige thema\'s en plugins zijn mogelijk nog niet beschikbaar.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'U kunt gelijk naar Piwigo %s updaten, zonder eerst up te daten naar Piwigo %s (aanbevolen).';
$lang['Save Template Directory'] = 'Sla sjabloon direcotry op';
$lang['Dump Database'] = 'Dump Database';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Gebruik geschiedenis data (Waarschuwing: het geheugen limiet van de server kan overschreden worden).';
$lang['Unable to write new local directory.'] = 'Kan niet naar de lokale map schrijven.';
$lang['Unable to send template directory.'] = 'Kan geen sjabloon map sturen.';
$lang['Unable to dump database.'] = 'Kan de database niet dumpen.';
$lang['Some upgrades are available for extensions.'] = 'Er zijn sommige updates beschikbaar voor de plugins.';
$lang['Ignore All'] = 'Negeer alles';
$lang['Crop'] = 'Inkorten';
$lang['Width'] = 'Breedte';
$lang['Height'] = 'Hoogte';
$lang['Follow Orientation'] = 'Volg orientatie';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Als je thumbnails wilt hergenereren, ga dan naar de <a href="%s">Batch Manager</a>.';
$lang['Graphics Library'] = 'Afbeeldings bibliotheek';
$lang['Average rate'] = 'Gemiddelde waardering';
$lang['Rate'] = 'Waardering';
$lang['Learn more'] = 'Leer meer';
$lang['An error has occured during upgrade.'] = 'Er is iets foutgegaan bij het bijwerken van Piwigo naar de nieuwste versie.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Er is iets foutgegaan bij het uitpakken. Controleer de bestandstoegangen van uw Piwigo-installatie.<br><a href="%s">Klik kier om de fout-logging weer te geven</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kan het upgrade-bestand niet van de server verkrijgen';
$lang['... or '] = '... of ';
$lang['Create'] = 'Aanmaken';
$lang['Start Upload'] = 'Start Upload';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Je gebruikt de Flash uploader. Problemen? Probeer de <a href="%s">Browser uploader</a> inplaats.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Je gebruikt de Browser uploader. Problemen? Probeer de  <a href="%s">Flash uploader</a> inplaats.';
$lang['Maximum file size: %sB.'] = 'Maximum bestands omvang: %sB.';
$lang['Allowed file types: %s.'] = 'Toegestane bestands typen: %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Geschatte maximale resolutie: %dM pixels (dat is %dx%d pixels).';
$lang['Manage Permissions'] = 'Beheer Permissies';
$lang['Photo %s of %s'] = 'Foto %s of %s';
$lang['show details'] = 'Toon details';
$lang['hide details'] = 'Verberg details';
$lang['Merge tags'] = 'Voeg tags samen';
$lang['Select the destination tag'] = 'Kies de bestemmings tag';
$lang['(this tag will be deleted)'] = '(Deze tag wordt verwijderd)';
$lang['Confirm merge'] = 'Bevestig samenvoegen';
$lang['Merge selected tags'] = 'Voeg geselecteerde tags samen';
$lang['No destination tag selected'] = 'Geen bestemmings tag geselecteerd';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> samengevoegd in tag <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Selecteer ten minste twee tags om samen te voegen';
$lang['Select an album'] = 'Kies een album';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Standaard zal Piwigo een nieuwe web formaat foto aanmaken van de HD (high definition) versie van je foto.';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Als geen HD beschikbaar is en de huidige web formaat foto is groter dan de nieuwe afmetingen, dan zal Piwigo het als HD gebruiken en daar een web formaat foto van maken.';
?>